import {
  schemeSpectral,
  scaleOrdinal,
  select,
  csv,
} from 'd3';
import { scatterPlot } from './scatterPlot';
import { colorLegend } from './colorLegend';

const svg = select('svg');
const scatterPlotG = svg.append('g');
const colorLegendG = svg.append('g');
const colorScale = scaleOrdinal();
const colorValue = d => d.cylinders;

// State and Event Handlers
let data;
let selectedColorValue;

const onClick = value => {
  selectedColorValue = value;
  render();
}
  
const render = () => {
  
  colorScale
    .domain(data.map(colorValue))
    .domain(colorScale.domain().sort())
    .range(schemeSpectral[colorScale.domain().length]);
  
  scatterPlotG.selectAll('g').remove();
  scatterPlotG.call(scatterPlot, {
      title: 'Cars: Horsepower vs. Weight',
      xValue: d => d.horsepower,
      xAxisLabel: 'Horsepower',
      yValue: d => d.weight,
      yAxisLabel: 'Weight',
      circleRadius: 10,
      colorScale,
      selectedColorValue,
      data: data,
      width: +svg.attr('width'),
      height: +svg.attr('height'),
    });
  
  colorLegendG.call(colorLegend, {
    title: 'Cylinders',
  	spacing: 20,
    colorScale,
    textOffset: 20,
    circleRadius: 10,
    backgroundRectWidth: 20,
    selectedColorValue,
    onClick,
    width: +svg.attr('width'),
    height: +svg.attr('height'),
  })
}

csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(carsData => {
    carsData.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;
    });
  	
  data = carsData;
  render();
});